pub struct CreditRegistrationAdminActionRow {Show 18 fields
pub id: Uuid,
pub created_at: DateTime<Utc>,
pub action: CreditRegistrationAdminAction,
pub target_kind: CreditRegistrationAdminActionTarget,
pub target_id: Option<Uuid>,
pub target_phase: Option<String>,
pub actor_user_id: Uuid,
pub actor_first_name: Option<String>,
pub actor_last_name: Option<String>,
pub actor_email: Option<String>,
pub actor_role: String,
pub actor_course_id: Option<Uuid>,
pub course_name: Option<String>,
pub reason: Option<String>,
pub before_state: Option<CreditRegistrationState>,
pub after_state: Option<CreditRegistrationState>,
pub details: Option<Value>,
pub affected_row_count: Option<i32>,
}Fields
id: Uuidcreated_at: DateTime<Utc>action: CreditRegistrationAdminActiontarget_kind: CreditRegistrationAdminActionTargettarget_id: Option<Uuid>None for a phase target, which is named by target_phase, and for a bulk action over a
selection, whose ids are in details.
target_phase: Option<String>actor_user_id: Uuidactor_first_name: Option<String>actor_last_name: Option<String>actor_email: Option<String>actor_role: Stringglobal_admin or course_teacher.
actor_course_id: Option<Uuid>The course whose edit permission authorised a teacher action.
course_name: Option<String>reason: Option<String>before_state: Option<CreditRegistrationState>after_state: Option<CreditRegistrationState>details: Option<Value>affected_row_count: Option<i32>Trait Implementations
Sourceimpl Clone for CreditRegistrationAdminActionRow
impl Clone for CreditRegistrationAdminActionRow
Sourcefn clone(&self) -> CreditRegistrationAdminActionRow
fn clone(&self) -> CreditRegistrationAdminActionRow
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for CreditRegistrationAdminActionRow
impl ComposeSchema for CreditRegistrationAdminActionRow
Sourceimpl<'de> Deserialize<'de> for CreditRegistrationAdminActionRow
impl<'de> Deserialize<'de> for CreditRegistrationAdminActionRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CreditRegistrationAdminActionRow
impl PartialEq for CreditRegistrationAdminActionRow
Sourcefn eq(&self, other: &CreditRegistrationAdminActionRow) -> bool
fn eq(&self, other: &CreditRegistrationAdminActionRow) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ToSchema for CreditRegistrationAdminActionRow
impl ToSchema for CreditRegistrationAdminActionRow
impl StructuralPartialEq for CreditRegistrationAdminActionRow